/**
 * Title:        GridSim Toolkit
 * Version:      GridSim  1.0, 12/09/2001
 * Description:  GridSim (Grid Simulation) Toolkit for Modeling and Simulation of
 *               Parallel and Distributed Systems such as Clusters and Grids
 * Authors:      Manzur Murshed and Rajkumar Buyya
 *               Monash University, Melbourne, Australia
 * Licence:      GPL - http://www.gnu.org/copyleft/gpl.html
 */

package gridsim;

/**
 * Classes related to GridSim Random Functions and Statistics
 */
public class Accumulator
{
  private int n;
  private double mean;
  private double sqr_mean;
  private double min;
  private double max;
  private double last;

  public Accumulator()
  {
    n = 0;
    mean = Double.NaN;
    sqr_mean = Double.NaN;
    min = Double.NaN;
    max = Double.NaN;
    last = Double.NaN;
  }

  public void add(double item, int times)
  {
    if(times<1)
      return;
    last = item;
    if(n <= 0)
    {
      n += times;
      mean = min = max = item;
      sqr_mean = item*item;
    }
    else
    {
      n += times;
      mean = ((n-times)*mean + item*times)/n;
      sqr_mean = ((n-times)*sqr_mean + item*item*times)/n;
      if(item<min)
        min = item;
      if(item>max)
          max = item;
    }
  }
  public void add(double item)
  {
    add(item, 1);
  }

  public double mean()
  {
    return mean;
  }

  // Standard deviation
  public double sd()
  {
    return sqr_mean - mean*mean;
  }

  public double min()
  {
    return min;
  }

  public double max()
  {
    return max;
  }

  public double last()
  {
    return last;
  }

  public int count()
  {
    return n;
  }

  public double sum()
  {
    return n*mean;
  }

  public static int ByteSize()
  {
    return 4 + 4*8;
  }
}
