/**
 * Title:        GridSim Toolkit
 * Version:      GridSim  1.0, 12/09/2001
 * Description:  GridSim (Grid Simulation) Toolkit for Modeling and Simulation of
 *               Parallel and Distributed Systems such as Clusters and Grids
 * Authors:      Manzur Murshed and Rajkumar Buyya
 *               Monash University, Melbourne, Australia
 * Licence:      GPL - http://www.gnu.org/copyleft/gpl.html
 */

package gridsim;


import java.util.*;
import java.io.*;
import eduni.simjava.*;

/**
 * A GridSim Random class that provides facility for
 * generating a number whole value is between bounds specified.
 * E.g., To produce a random number between 18.00 and 22.00 one can invoke
 * real(20.0, 0.1, 0.1, randDouble) where randDouble comes from java Random.
 */
public class GridSimRandom
{
  private static Random r;  // random number from Java
  // Factor values for Network IO
  private static double less_factor_io;
  private static double more_factor_io;
  // Factor values for Execution
  private static double less_factor_e;
  private static double more_factor_e;

  public GridSimRandom() {
    this.r = new Random(1234);
    this.less_factor_io = 0.0;
    this.more_factor_io = 0.0;
    this.less_factor_e = 0.0;
    this.more_factor_e = 0.0;
  }

  public GridSimRandom(long seed)
  {
    this.r = new Random(seed);
    this.less_factor_io = 0.0;
    this.more_factor_io = 0.0;
    this.less_factor_e = 0.0;
    this.more_factor_e = 0.0;
  }

  public GridSimRandom(long seed, double less_factor_io, double more_factor_io, double less_factor_e, double more_factor_e)
  {
    this.r = new Random(seed);
    this.less_factor_io = less_factor_io;
    this.more_factor_io = more_factor_io;
    this.less_factor_e = less_factor_e;
    this.more_factor_e = more_factor_e;
  }

  public static void set_factors(double less_factor_io_value, double more_factor_io_value, double less_factor_e_value, double more_factor_e_value)
  {
    less_factor_io = less_factor_io_value;
    more_factor_io = more_factor_io_value;
    less_factor_e = less_factor_e_value;
    more_factor_e = more_factor_e_value;
  }

  public static int int_sample(int range) {
    return r.nextInt(range);
  }

  public static double double_sample() {
    return r.nextDouble();
  }

  public static void set_less_factor_io(double factor) {
    less_factor_io = factor;
  }

  public static void set_more_factor_io(double factor) {
    more_factor_io = factor;
  }

  public static void set_less_factor_e(double factor) {
    less_factor_e = factor;
  }

  public static void set_more_factor_e(double factor) {
    more_factor_e = factor;
  }

  public static double get_factor_io() {
    return (more_factor_io - less_factor_io)/2;
  }

  public static double get_factor_e() {
    return (more_factor_e - less_factor_e)/2;
  }

  public static double real(double d, double less_factor,
                            double more_factor, double randDouble) {
    return d*(1.0 - less_factor + (less_factor + more_factor)*randDouble);
  }

  public static double real_io(double d) {
    return real(d, less_factor_io, more_factor_io, double_sample());
  }

  public static double real_e(double d) {
    return real(d, less_factor_e, more_factor_e, double_sample());
  }

  public static double expected_io(double d) {
    return d*(1.0 + get_factor_io());
  }

  public static double expected_e(double d) {
    return d*(1.0 + get_factor_e());
  }
}