/**
 * Title:        GridSim Toolkit
 * Version:      GridSim  1.0, 12/09/2001
 * Description:  GridSim (Grid Simulation) Toolkit for Modeling and Simulation of
 *               Parallel and Distributed Systems such as Clusters and Grids
 * @author       R. Buyya and M. Murshed (by surname)
 *               Monash University, Melbourne, Australia
 * Licence:      GPL - http://www.gnu.org/copyleft/gpl.html
 */

package gridsim;

import java.util.*;
import java.io.*;
import eduni.simjava.*;
import gridsim.*;

/**
 * Classes related to GridSim Jobs: called Gridlet
 */

public class Gridlet {
  private int user_id;      // the User or Broker ID. It is advisable that broker set this ID
                            // with its own ID, so that GridResource returns to it after the execution.
  int gridlet_id;           // Gridlet ID
  private double gridlet_length; // in MI
  private long GridletFileSize; // in byte = program + input data size
  private long GridletOutputSize; // in byte
  private int resource_id;       // the resource on which Gridlet executed
  private double CostPerSec;     // Agreed cost (G$) of Resource/CPU-sec
  private double ExecStartTime; // Start time of Gridlet execution
  // Gridlet SubmitTime is required since Gridlet execution may not start immediately.
  // This particularly important when we go for Space Shared machine for SPACE shared
  private double WallClockTime; // Gridlets in seconds
  private double actualCPUTime; // in seconds
  private int status; // 0 = created; 1 = ready; 2 = queued; 3 = in execution; 4 = success; 5 = fail

  public static final int CREATED = 0; // added to gridlet list
  public static final int READY = 1; // broker assigned to a resource as plan
  public static final int QUEUED = 2; // gridlet actually moved to Grid node
  public static final int INEXEC = 3; // gridlet in exec on grid node
  public static final int SUCCESS = 4; // gridlet successful
  public static final int FAILED = 5;   // gridlet failed

//  public Gridlet(int user_id, int gridlet_id, double gridlet_length,
  public Gridlet(int gridlet_id, double gridlet_length,
              long GridletFileSize, long GridletOutputSize) {
    this.user_id = -1;              // to be set by the Broker
    this.gridlet_id = gridlet_id;
    this.gridlet_length = gridlet_length;
    this.status = CREATED;
    this.GridletFileSize = GridletFileSize;
    this.GridletOutputSize = GridletOutputSize;
  }

  public int GetGridletID() {
    return gridlet_id;
  }

  public void SetUserID(int id) {
    user_id = id;
  }

  public int GetUserID() {
    return user_id;
  }

  public int GetResourceID() {
    return resource_id;
  }

  public long GetGridletFileSize() {
    return GridletFileSize;
  }

  public long GetGridletOutputSize() {
    return GridletOutputSize;
  }

  public void SetResParam(int resource_id, double CostPerSec) {
    this.resource_id = resource_id;
    this.CostPerSec = CostPerSec;
  }

  public void SetExecStartTime( double clocktime )
  {
    ExecStartTime = clocktime;
  }

  public double getExecStartTime()
  {
    return ExecStartTime;
  }

  public void SetExecParam(double WallClockTime, double actualCPUTime) {
    this.WallClockTime = WallClockTime;
    this.actualCPUTime = actualCPUTime;
  }

  public void SetStatus(int status) {
    this.status = status;
  }

  // returns the status code of Gridlet
  public int GetStatus() {
    return status;
  }

  // Returns the Gridlet status as ASCII text (e.g., "Created")
  public String GetStatusString()
  {
    String statusString = new String();
    switch( status )
    {
      case CREATED:
        statusString = "Created";
        break;
      case READY:
        statusString = "Ready";
        break;
      case INEXEC:
        statusString = "InExec";
        break;
      case SUCCESS:
        statusString = "Success";
        break;
      case FAILED:
        statusString = "Failed";
        break;
    }
    return statusString;
  }

  public double GetGridletLength() {
    return gridlet_length;
  }

  public double GetActualCPUTime() {
    return actualCPUTime;
  }

  public double GetCostPerSec() {
    return CostPerSec;
  }

  public double GetWallClockTime() {
    return WallClockTime;
  }

  public double GetFinishTime() {
    return ExecStartTime+WallClockTime;
  }
}
